//---------------------------------------------------------------------------
// Code to flash LED and turn on other LEDs when switches are pressed

//---------------------------------------------------------------------------
// Header files

#include <p30f6014.h>             //Standard header file

//---------------------------------------------------------------------------
// Configuration bits

   _FOSC(CSW_FSCM_OFF & XT_PLL4);   //XT with 4xPLL oscillator, Failsafe clock off
   _FWDT(WDT_OFF);                  //Watchdog timer disabled
   _FBORPOR(PBOR_OFF & MCLR_EN);    //Brown-out reset disabled, MCLR reset enabled
   _FGS(CODE_PROT_OFF);             //Code protect disabled

//---------------------------------------------------------------------------
// Definitions

#define Fcy 7370000                 //7.37MHz oscillator with 4xPLL -> 7.37MIPs

//---------------------------------------------------------------------------
// Main routine
//---------------------------------------------------------------------------

int main(void)
{		
//------------------------------------------------------------------------------
//Initialize LED outputs on PORTD bits 0-4 and switch inputs on PORTA bits 12 - 14

	LATD = 0xFFFF;                //Turn off all LEDS ****ACTIVE LOW****
   TRISD = 0xFFF0;               //Set LED pins as outputs
   TRISA = 0xFFFF;               //Set pushbutton switch pins as inputs

//------------------------------------------------------------------------------
//Initialize Timer1 for 1/2 second period

   T1CON = 0;                    //Turn off Timer1 by clearing control register
	TMR1 = 0;                     //Start Timer1 at zero
	PR1 = (Fcy/256)/2;            //Set period register value for 1/2 second 
   T1CON = 0x8030;               //Configure Timer1 (timer on, continue in IDLE, not gated, 1:256 prescaler, internal clock)

//------------------------------------------------------------------------------
//Enable INT1 and INT2 interrupts

	IEC1bits.INT1IE = 1;	   	   //Enable INT1 interrupt
	IEC1bits.INT2IE = 1;	   	   //Enable INT2 interrupt


//------------------------------------------------------------------------------
//Loop while flashing LED1

   while (1)
   {
      if(IFS0bits.T1IF == 1)     //Check if Timer1 interrupt flag is set
	   {
      IFS0bits.T1IF = 0;         //Clear Timer1 interrupt flag
      LATDbits.LATD0 = !LATDbits.LATD0; //Toggle LED1
      }
	}
}

//---------------------------------------------------------------------------
// INT1 Interrupt Service Routine 
//---------------------------------------------------------------------------

void _ISR _INT1Interrupt(void) //Declare INT1 interrupt function
{
   IFS1bits.INT1IF = 0;		 //Clear INT1 interrupt flag
   LATDbits.LATD2 = 0;     //Turn LED3 on
   LATDbits.LATD3 = 1;     //Turn LED4 off
}

//---------------------------------------------------------------------------
// INT2 Interrupt Service Routine
//---------------------------------------------------------------------------

void _ISR _INT2Interrupt(void) //Declare INT2 interrupt function
{
   IFS1bits.INT2IF = 0;		 //Clear INT2 interrupt flag
   LATDbits.LATD2 = 1;     //Turn LED3 off
   LATDbits.LATD3 = 0;     //Turn LED4 on
}
