//---------------------------------------------------------------------------
// Code to flash two LEDs with timer interrupts at different priorities.

//---------------------------------------------------------------------------
// Header files

#include <p30f6014.h>               //Standard header file

//---------------------------------------------------------------------------
// Configuration bits

   _FOSC(CSW_FSCM_OFF & XT_PLL4);   //XT with 4xPLL oscillator, Failsafe clock off
   _FWDT(WDT_OFF);                  //Watchdog timer disabled
   _FBORPOR(PBOR_OFF & MCLR_EN);    //Brown-out reset disabled, MCLR reset enabled
   _FGS(CODE_PROT_OFF);             //Code protect disabled

//---------------------------------------------------------------------------
// Definitions

#define Fcy 7370000                 //7.37MHz oscillator with 4xPLL -> 7.37MIPs
#define SW1	!PORTAbits.RA12			//SW1 defined as active low RA12 
//---------------------------------------------------------------------------
// Main routine
//---------------------------------------------------------------------------

int main(void)
{		
//------------------------------------------------------------------------------
//Initialize LED outputs on PORTD bits 0-4 and switch inputs on PORTA bits 12-15

	LATD = 0xFFFF;                     //Turn off all LEDS
   TRISD = 0xFFF0;               //Set LED pins as outputs
   TRISA = 0xFFFF;               //Set pushbutton switch pins as inputs

//------------------------------------------------------------------------------
//Set CPU priority

   'Replace text with code   //Set core priority level to 4

//------------------------------------------------------------------------------
//Initialize Timer1 for 1/10 second period

   T1CON = 0;                    //Turn off Timer1 by clearing control register
	TMR1 = 0;                     //Start Timer1 at zero
	PR1 = (Fcy/256)/10;           //Set Timer1 period register value for 1/10 second 
   T1CON = 0x8030;               //Configure Timer1 (timer on, continue in IDLE, not gated, 1:256 prescaler, internal clock)

//------------------------------------------------------------------------------
//Set Timer 1 interrupt priority and enable interrupt

  	'Replace text with code 				//Set Timer1 interrupt priority level to 3
   IFS0bits.T1IF = 0;            //Clear Timer1 interrupt flag
   IEC0bits.T1IE = 1;            //Enable Timer1 interrupt

//------------------------------------------------------------------------------
//Initialize Timer2 for one second period

   T2CON = 0;                    //Turn off Timer2 by clearing control register
	TMR2 = 0;                     //Start Timer2 at zero
	PR2 = (Fcy/256);              //Set Timer2 period register value for 1 second 
   T2CON = 0x8030;               //Configure Timer2 (timer on, continue in IDLE, not gated, 1:256 prescaler, internal clock)

//------------------------------------------------------------------------------
//Set Timer 2 interrupt priority and enable interrupt

   'Replace text with code				 //Set Timer2 interrupt priority level to 5
   IFS0bits.T2IF = 0;            //Clear Timer2 interrupt flag
   IEC0bits.T2IE = 1;            //Enable Timer2 interrupt

//------------------------------------------------------------------------------
//Loop while testing switch SW1 (active low) and change CPU priority accordingly

   'Replace text with code				 //Wait for SW1 to be pressed

   while (1)
   {
      if(!SW1) 					        //If SW1 is not pressed
		{
         LATDbits.LATD3 = 1;     //Turn LED4 off
         SRbits.IPL = 2;         //Set core priority level to 2
      }
      else                       //If SW1 is pressed
		{
         LATDbits.LATD3 = 0;     //Turn LED4 on
         SRbits.IPL = 6;         //Set core priority level to 6
      }
	}
}

//---------------------------------------------------------------------------
// Timer 1 Interrupt Service Routine
//---------------------------------------------------------------------------

void _ISR _T1Interrupt(void)
{
   IFS0bits.T1IF = 0;            //Clear Timer1 interrupt flag
	LATDbits.LATD0 = 0;           //Turn LED1 on
  'Replace text with code		 //Wait for next Timer1 interrupt flag 
   IFS0bits.T1IF = 0;            //Clear Timer1 interrupt flag
	LATDbits.LATD0 = 1;           //Turn LED1 off
}

//---------------------------------------------------------------------------
// Timer 2 Interrupt Service Routine
//---------------------------------------------------------------------------

void _ISR _T2Interrupt(void)
{
   IFS0bits.T2IF = 0;            //Clear Timer2 interrupt flag
	LATDbits.LATD1 = 0;           //Turn LED2 on
   while(IFS0bits.T2IF == 0);    //Wait for next Timer2 interrupt flag 
   IFS0bits.T2IF = 0;            //Clear Timer2 interrupt flag
	LATDbits.LATD1 = 1;           //Turn LED2  off
}
