/*;------------------------------------------------------------------------------
; Read ADC and plot voltage on the LCD display
;------------------------------------------------------------------------------
*/
	#include <p30fXXXX.h>
	#include <dsp.h>
	#include <math.h>
	#include "LCD_Display.h"

	#define NUM_SAMPLES       256
	#define FilteredButton		PORTAbits.RA13
	#define UnfilteredButton 	PORTAbits.RA12

/* externs... from Filter Source File generated from dsPIC Filter Design */
/* NOTE:  your filter structure names will differ */
extern FIRStruct fir_test1Filter;
extern FIRStruct f_solutionFilter;

_FOSC(CSW_FSCM_OFF & XT_PLL4);
_FWDT(WDT_OFF);
_FBORPOR(PBOR_ON & BORV_42 & PWRT_OFF & MCLR_EN);
_FGS(CODE_PROT_OFF);

unsigned int fsample, freqa, freqb, freqc;
int array[NUM_SAMPLES];
int array_plot[NUM_SAMPLES];
unsigned int max_magnitude;

fractional filter_output_array[NUM_SAMPLES];
float fINA[NUM_SAMPLES]; 
float fINB[NUM_SAMPLES]; 
float fINC[NUM_SAMPLES];

void makewaves(void)
{
		unsigned int n;

		fsample = 10000;		// 10 Khz sampling example
		freqa   = 	847;		// 847 Hz sine wave
		freqb	=	367;		// 367 Hz sine wave
		freqc 	= 	123;		// 123 Hz sine wave
			
			for (n=0; n < NUM_SAMPLES; n++)
			{
					fINA[n] = sin((2*PI*freqa*n)/fsample);				// Create sine wave of Frequency freqa
					fINB[n] = sin((2*PI*freqb*n)/fsample);				// Create sine wave of Frequency freqb
					fINC[n] = sin((2*PI*freqc*n)/fsample);				// Create sine wave of Frequency freqc
					array[n] = ((fINA[n]+fINB[n]+fINC[n])/3)*0x8000;	// Scaled as fractional integer values
					array_plot[n] = ((array[n]+0x8000)/256);     		// Scaled for UART Charting Utility
			}
				
}


void Filter (void)
{
   int average;
   unsigned u;

	/* Call FIR filter initialization here */
	'Replace text with code // Call FIR filter initialization

	// Extra Credit:	Clear timer 1
	// Extra Credit:	Set up Timer 1 (T1CON) with Timer ON, Gate Disabled, 1:1 Prescaller, Internal Clock

	/* Call FIR filter here */
 	'Replace text with code // Call FIR filter initialization

   // Extra Credit:	Turn Timer OFF

   /* compute the average of output[] */
   /* this helps tune the level shifter */
   average = 0;
   for (u=0; u<NUM_SAMPLES; u++)
   {
      average += filter_output_array[u];
   }
   average = average / NUM_SAMPLES;

   /* remove the average from the filter output */
   /* this has the effect of removing a DC offset... */
   for (u=0; u<NUM_SAMPLES; u++)
   {
      filter_output_array[u] -= average;
	  filter_output_array[u] = (filter_output_array[u] + 0x8000)/256;
   }

}  /* end Filter() */

int main(void)
{
	UART_Display_Setup();	// Set up UART1 for dsPIC->PC display communications for SimpleChart waveform plotting
	LCD_Display_Setup();	// Set up LCD display to display waveform outputs
	makewaves();			// Generate multiple tone waveform		
	Filter();				// Filter out unwanted frequency components

		while(1)			
		{
		if(!UnfilteredButton){							// Update display with Input data if Unfiltered button is pressed
			UART_Display(NUM_SAMPLES,array_plot);		// Display filter input multiple tone waveform
			LCD_Display_array(array_plot);
			while(!UnfilteredButton);					// Wait for Unfiltered Button to be released
			}
		if(!FilteredButton){								// Update display with Filter output data if Filtered button is pressed
			UART_Display(NUM_SAMPLES,filter_output_array);	// Display output of filter
			LCD_Display_array(filter_output_array);
			while(!FilteredButton);						// Wait for Filtered button to be released
			}
		}
}


